/******************************************************************************
* Copyright (C) 2008 - Ikaro Games   www.ikarogames.com                       *
*                                                                             *
* This program is free software; you can redistribute it and/or               *
* modify it under the terms of the GNU General Public License                 *
* as published by the Free Software Foundation; either version 2              *
* of the License, or (at your option) any later version.                      *
*                                                                             *
* This program is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of              *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
* GNU General Public License for more details.                                *
*                                                                             *
* You should have received a copy of the GNU General Public License           *
* along with this program; if not, write to the Free Software                 *
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. *
*                                                                             *
*                                                                             *
*       generated by dia/DAOcodegen.py                                        *
*       Version: 1.8                                                          *
******************************************************************************/

#include "CMasterDAOFactorySQLite.h"
#include "../../../../../utils/CLog.h"

CMasterDAOFactorySQLite::CMasterDAOFactorySQLite(std::string file)
{
    CLog::getInstance()->info("Path: %s", file.c_str());
    if( sqlite3_open(file.c_str(), &m_database )!=SQLITE_OK ){
        sqlite3_close(m_database);
        m_database = NULL;
        CLog::getInstance()->exception("Can't open database file: \"%s\" --> \"%s\"", file.c_str(), sqlite3_errmsg(m_database));
    }

    m_PfGamesDAOSQLite = new CPfGamesDAOSQLite(m_database);
    m_PfUsersDAOSQLite = new CPfUsersDAOSQLite(m_database);

    CLog::getInstance()->info("SQLite Database open: <-- \"%s\"", file.c_str());
}

CMasterDAOFactorySQLite::~CMasterDAOFactorySQLite()
{
    delete m_PfGamesDAOSQLite;
    delete m_PfUsersDAOSQLite;

    sqlite3_close(m_database);
    CLog::getInstance()->info("SQLite Database closed");
}

bool CMasterDAOFactorySQLite::createSchema()
{
    std::string sql = "";
    sql += "BEGIN TRANSACTION;";
    sql += "CREATE TABLE PF_GAMES";
    sql += "(";
    sql += "  X_FK_USER INTEGER";
    sql += "  ,S_CONNECTION_STRING TEXT";
    sql += "  ,X_GAME INTEGER PRIMARY KEY AUTOINCREMENT";
    sql += "  ,S_DRIVER_NAME TEXT";
    sql += "  ,S_GAME_NAME TEXT";
    sql += ");";
    sql += "CREATE TABLE PF_USERS";
    sql += "(";
    sql += "  X_USER INTEGER PRIMARY KEY AUTOINCREMENT";
    sql += "  ,S_USER TEXT";
    sql += ");";
    sql += "CREATE INDEX PF_GAMES_X_FK_USER ON PF_GAMES (X_FK_USER);";
    sql += "CREATE INDEX PF_GAMES_X_GAME ON PF_GAMES (X_GAME);";
    sql += "CREATE INDEX PF_USERS_X_USER ON PF_USERS (X_USER);";
    sql += "COMMIT;";

    char *msgError = NULL;
    bool correct = true;
    if( sqlite3_exec(m_database, sql.c_str(), NULL, NULL, &msgError)!=SQLITE_OK ){
        CLog::getInstance()->error("Error in SQL: \"%s\" --> \"%s\"", sql.c_str(), msgError);
        sqlite3_free(msgError);
        correct = false;
    }
    return correct;
}

IPfGamesDAO* CMasterDAOFactorySQLite::getIPfGamesDAO()
{
    return m_PfGamesDAOSQLite;
}

IPfUsersDAO* CMasterDAOFactorySQLite::getIPfUsersDAO()
{
    return m_PfUsersDAOSQLite;
}

